==> mx-cleanup_20.6.1.tar.xz: mx-cleanup-20.6.1/translations/mx-cleanup_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="14"/>
        <location filename="../mainwindow.cpp" line="53"/>
        <location filename="../mainwindow.cpp" line="246"/>
        <location filename="../mainwindow.cpp" line="292"/>
        <source>MX Cleanup</source>
        <translation>MX Porządki</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="26"/>
        <source>Clean Folders</source>
        <translation>Wyczyść foldery</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="86"/>
        <source>Delete Logs</source>
        <translation>Usuń dzienniki (logi)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="98"/>
        <source>Old logs</source>
        <translation>Stare dzienniki</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="117"/>
        <source>All logs</source>
        <translation>Wszystkie dzienniki</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="130"/>
        <location filename="../mainwindow.ui" line="387"/>
        <location filename="../mainwindow.ui" line="451"/>
        <source>Don&apos;t empty</source>
        <translation>Nie opróżniaj</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="192"/>
        <source>Display help </source>
        <translation>Wyświetl pomoc</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="195"/>
        <source>Help</source>
        <translation>Pomoc</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="202"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="231"/>
        <source>About this application</source>
        <translation>O programie</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="234"/>
        <source>About...</source>
        <translation>O...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="241"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="273"/>
        <source>Quit application</source>
        <translation>Zakończ aplikację</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="276"/>
        <source>Close</source>
        <translation>Zamknij</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="283"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="321"/>
        <source>Apply</source>
        <translation>Zastosuj</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="349"/>
        <source>Empty Trash</source>
        <translation>Opróżnij kosz</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="364"/>
        <source>Selected user</source>
        <translation>Wybrany użytkownik</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="380"/>
        <source>All users</source>
        <translation>Wszyscy użytkownicy</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="416"/>
        <source>Clear APT Cache</source>
        <translation>Wyczyść pamięć podręczną APT</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="428"/>
        <source>Old files</source>
        <translation>Stare pliki</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="444"/>
        <source>All files</source>
        <translation>Wszystkie pliki</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="480"/>
        <source>Free Disk Space for User</source>
        <translation>Zwolnij miejsce na dysku dla użytkownika</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="492"/>
        <location filename="../mainwindow.ui" line="505"/>
        <source>Select user to repair</source>
        <translation>Wybierz użytkownika do naprawy</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="508"/>
        <source>Select user:</source>
        <translation>Wybierz użytkownika:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="524"/>
        <source>Graphical Tool for Analyzing Disk Usage</source>
        <translation>Narzędzie graficzne do analizy wykorzystania dysku</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="530"/>
        <source>Run Disk Usage Analyzer</source>
        <translation>Uruchom Analizator wykorzystania dysku</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="544"/>
        <source>Schedule</source>
        <translation>Harmonogram</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="556"/>
        <source>No automatic clean</source>
        <translation>Nie czyść automatycznie</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="563"/>
        <source>Daily</source>
        <translation>Codziennie</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="570"/>
        <source>Weekly</source>
        <translation>Co tydzień</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="577"/>
        <source>Monthly</source>
        <translation>Co miesiąc</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="237"/>
        <source>Done</source>
        <translation>Gotowe</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="238"/>
        <source>Cleanup command done</source>
        <translation>Wykonano polecenie czyszczenia</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="239"/>
        <source>%1 MiB were freed</source>
        <translation>%1 MiB zostało uwolnione</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="246"/>
        <source>About</source>
        <translation>O</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="247"/>
        <source>Version: </source>
        <translation>Wersja:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="248"/>
        <source>Quick and safe removal of old files</source>
        <translation>Szybkie i bezpieczne usuwanie starych plików</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="250"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Prawa autorskie © MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="251"/>
        <location filename="../mainwindow.cpp" line="261"/>
        <source>License</source>
        <translation>Licencja</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="252"/>
        <location filename="../mainwindow.cpp" line="267"/>
        <source>Changelog</source>
        <translation>Dziennik zmian</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="253"/>
        <source>Cancel</source>
        <translation>Anuluj</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="274"/>
        <source>&amp;Close</source>
        <translation>&amp;Zamknij</translation>
    </message>
</context>
<context>
    <name>QApplication</name>
    <message>
        <location filename="../main.cpp" line="52"/>
        <source>You must run this program as root.</source>
        <translation>Musisz uruchomić ten program jako administrator. </translation>
    </message>
</context>
</TS>

==> mx-cleanup_20.7.tar.xz: mx-cleanup-20.7/translations/mx-cleanup_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="14"/>
        <location filename="../mainwindow.cpp" line="53"/>
        <location filename="../mainwindow.cpp" line="263"/>
        <location filename="../mainwindow.cpp" line="309"/>
        <source>MX Cleanup</source>
        <translation>MX Porządki</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="26"/>
        <source>Clean Folders</source>
        <translation>Wyczyść foldery</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="566"/>
        <source>Delete Logs</source>
        <translation>Usuń dzienniki (logi)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="617"/>
        <source>Old logs</source>
        <translation>Stare dzienniki</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="591"/>
        <source>All logs</source>
        <translation>Wszystkie dzienniki</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="289"/>
        <location filename="../mainwindow.ui" line="411"/>
        <location filename="../mainwindow.ui" line="604"/>
        <source>Don&apos;t empty</source>
        <translation>Nie opróżniaj</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="119"/>
        <source>Display help </source>
        <translation>Wyświetl pomoc</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="122"/>
        <source>Help</source>
        <translation>Pomoc</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="129"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="158"/>
        <source>About this application</source>
        <translation>O programie</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="161"/>
        <source>About...</source>
        <translation>O...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="168"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="200"/>
        <source>Quit application</source>
        <translation>Zakończ aplikację</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="203"/>
        <source>Close</source>
        <translation>Zamknij</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="210"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="248"/>
        <source>Apply</source>
        <translation>Zastosuj</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="276"/>
        <source>Empty Trash</source>
        <translation>Opróżnij kosz</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="331"/>
        <source>Selected user</source>
        <translation>Wybrany użytkownik</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="315"/>
        <source>All users</source>
        <translation>Wszyscy użytkownicy</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="282"/>
        <source>Trash older than:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="296"/>
        <location filename="../mainwindow.ui" line="630"/>
        <source> days</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="376"/>
        <source>Clear APT Cache</source>
        <translation>Wyczyść pamięć podręczną APT</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="388"/>
        <source>Old files</source>
        <translation>Stare pliki</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="404"/>
        <source>All files</source>
        <translation>Wszystkie pliki</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="440"/>
        <source>Free Disk Space for User</source>
        <translation>Zwolnij miejsce na dysku dla użytkownika</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="452"/>
        <location filename="../mainwindow.ui" line="465"/>
        <source>Select user to repair</source>
        <translation>Wybierz użytkownika do naprawy</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="468"/>
        <source>Select user:</source>
        <translation>Wybierz użytkownika:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="484"/>
        <source>Graphical Tool for Analyzing Disk Usage</source>
        <translation>Narzędzie graficzne do analizy wykorzystania dysku</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="490"/>
        <source>Run Disk Usage Analyzer</source>
        <translation>Uruchom Analizator wykorzystania dysku</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="504"/>
        <source>Schedule</source>
        <translation>Harmonogram</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="516"/>
        <source>No automatic clean</source>
        <translation>Nie czyść automatycznie</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="523"/>
        <source>Daily</source>
        <translation>Codziennie</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="530"/>
        <source>Weekly</source>
        <translation>Co tydzień</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="537"/>
        <source>Monthly</source>
        <translation>Co miesiąc</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="646"/>
        <source>Logs older than:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="254"/>
        <source>Done</source>
        <translation>Gotowe</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="255"/>
        <source>Cleanup command done</source>
        <translation>Wykonano polecenie czyszczenia</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="256"/>
        <source>%1 MiB were freed</source>
        <translation>%1 MiB zostało uwolnione</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="263"/>
        <source>About</source>
        <translation>O</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="264"/>
        <source>Version: </source>
        <translation>Wersja:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="265"/>
        <source>Quick and safe removal of old files</source>
        <translation>Szybkie i bezpieczne usuwanie starych plików</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="267"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Prawa autorskie © MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="268"/>
        <location filename="../mainwindow.cpp" line="278"/>
        <source>License</source>
        <translation>Licencja</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="269"/>
        <location filename="../mainwindow.cpp" line="284"/>
        <source>Changelog</source>
        <translation>Dziennik zmian</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="270"/>
        <source>Cancel</source>
        <translation>Anuluj</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="291"/>
        <source>&amp;Close</source>
        <translation>&amp;Zamknij</translation>
    </message>
</context>
<context>
    <name>QApplication</name>
    <message>
        <location filename="../main.cpp" line="52"/>
        <source>You must run this program as root.</source>
        <translation>Musisz uruchomić ten program jako administrator. </translation>
    </message>
</context>
</TS>
